=============================
Python MicroService framework
=============================

.. image:: https://travis-ci.org/palankai/pyrs.svg?branch=master
    :target: https://travis-ci.org/palankai/pyrs

.. image:: https://coveralls.io/repos/palankai/pyrs/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/palankai/pyrs?branch=master

.. image:: https://readthedocs.org/projects/pyrs/badge/?version=latest
    :target: https://readthedocs.org/projects/pyrs/?badge=latest
    :alt: Documentation Status

Main propose of this framework provide an independent architecture
and it should be used for any python framework (Django, Flask, Odoo).

This is just an umbrella package.
Provide some library to others.
